
var margin = {top: 20, right: 20, bottom: 30, left: 50},
    width = 960 - margin.left - margin.right,
    height = 500 - margin.top - margin.bottom;

// parse the date / time
var parseTime = d3.timeParse("%d-%m-%Y");

// set the ranges
var x = d3.scaleTime().range([0, width]);
var y = d3.scaleLinear().range([height, 0]);

// define the 1st line
var valueline = d3.line()
    .x(function(d) { return x(d.week_ended); })
    .y(function(d) { return y(d.total_week_5ya_deaths); });

// define the 2nd line
var valueline2 = d3.line()
    .x(function(d) { return x(d.week_ended); })
    .y(function(d) { return y(d.total_week_deaths); });


// append the svg obgect to the body of the page
// appends a 'group' element to 'svg'
// moves the 'group' element to the top left margin
var svg = d3.select("body").append("svg")
    .attr("width", width + margin.left + margin.right)
    .attr("height", height + margin.top + margin.bottom)
  .append("g")
    .attr("transform",
          "translate(" + margin.left + "," + margin.top + ")");

// Get the data
d3.csv("data.csv").then(function(data) {
	console.log(data)
  // format the data
  data.map(function(d) {
 				d.week_ended = parseTime(d.week_ended);
        d.total_week_deaths = +d.total_week_deaths;
        d.total_week_5ya_deaths = +d.total_week_5ya_deaths;      
  })
  data = data.filter(function(d) { return d.total_week_deaths > 0});
  
  // Scale the range of the data
  x.domain(d3.extent(data, function(d) { return d.week_ended; }));
  y.domain([d3.min(data, function(d) {
	  					return Math.min(
                d.total_week_deaths, d.total_week_5ya_deaths) - 1000
  					}),
            d3.max(data, function(d) {
	  					return Math.max(
                d.total_week_deaths, d.total_week_5ya_deaths) + 1000; 
            })
           ]);

  // Add the valueline path.
  svg.append("path")
      .data([data])
      .attr("class", "line line-avg")
      .attr("d", valueline);

  // Add the valueline2 path.
  svg.append("path")
      .data([data])
      .attr("class", "line")
      .style("stroke", "red")
      .attr("d", valueline2);

  // Add the X Axis
  svg.append("g")
      .attr("transform", "translate(0," + height + ")")
      .call(d3.axisBottom(x));

  // Add the Y Axis
  svg.append("g")
      .call(d3.axisLeft(y));

});